@@ -30,7 +30,6 @@
 
 #include <config.h>
 
-#include "gtkalias.h"
 #include "gtkactiongroup.h"
 #include "gtkstock.h"
 #include "gtktoggleaction.h"
@@ -38,6 +37,7 @@
 #include "gtkaccelmap.h"
 #include "gtkmarshalers.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 #define GTK_ACTION_GROUP_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_ACTION_GROUP, GtkActionGroupPrivate))
 
@@ -546,7 +546,7 @@ gtk_action_group_add_action (GtkActionGroup *action_group,
   g_hash_table_insert (action_group->private_data->actions, 
 		       g_strdup (gtk_action_get_name (action)),
                        g_object_ref (action));
-  g_object_set (G_OBJECT (action), "action_group", action_group, NULL);
+  g_object_set (action, "action_group", action_group, NULL);
 }
 
 /**
@@ -1076,6 +1076,9 @@ gtk_action_group_translate_string (GtkActionGroup *action_group,
   
   g_return_val_if_fail (GTK_IS_ACTION_GROUP (action_group), string);
   
+  if (string == NULL)
+    return NULL;
+
   translate_func = action_group->private_data->translate_func;
   translate_data = action_group->private_data->translate_data;
   
@@ -1117,3 +1120,6 @@ _gtk_action_group_emit_post_activate (GtkActionGroup *action_group,
 {
   g_signal_emit (action_group, action_group_signals[POST_ACTIVATE], 0, action);
 }
+
+#define __GTK_ACTION_GROUP_C__
+#include "gtkaliasdef.c"
