@@ -20,7 +20,6 @@
 #include <config.h>
 #include <string.h>
 
-#include "gtkalias.h"
 #include "gtkintl.h"
 #include "gtkbin.h"
 #include "gtkentry.h"
@@ -29,6 +28,7 @@
 #include "gtkcellrenderertext.h"
 #include "gtkcombobox.h"
 #include "gtkcomboboxentry.h"
+#include "gtkalias.h"
 
 static void gtk_cell_renderer_combo_class_init (GtkCellRendererComboClass *klass);
 static void gtk_cell_renderer_combo_init       (GtkCellRendererCombo      *self);
@@ -254,6 +254,7 @@ gtk_cell_renderer_combo_editing_done (GtkCellEditable *combo,
   GtkTreeIter iter;
   GtkCellRendererCombo *cell;
   GtkEntry *entry;
+  gboolean canceled;
 
   cell = GTK_CELL_RENDERER_COMBO (data);
 
@@ -262,12 +263,11 @@ gtk_cell_renderer_combo_editing_done (GtkCellEditable *combo,
       g_signal_handler_disconnect (combo, cell->focus_out_id);
       cell->focus_out_id = 0;
     }
-
-  if (_gtk_combo_box_editing_canceled (GTK_COMBO_BOX (combo)))
-    {
-      gtk_cell_renderer_editing_canceled (GTK_CELL_RENDERER (data));
-      return;
-    }
+  
+  canceled = _gtk_combo_box_editing_canceled (GTK_COMBO_BOX (combo));
+  gtk_cell_renderer_stop_editing (GTK_CELL_RENDERER (data), canceled);
+  if (canceled)
+    return;
 
   if (GTK_IS_COMBO_BOX_ENTRY (combo))
     {
@@ -392,3 +392,6 @@ gtk_cell_renderer_combo_start_editing (GtkCellRenderer     *cell,
 
   return GTK_CELL_EDITABLE (combo);
 }
+
+#define __GTK_CELL_RENDERER_COMBO_C__
+#include "gtkaliasdef.c"
