@@ -29,7 +29,6 @@
 #include <string.h>
 #include <math.h>
 
-#include "gtkalias.h"
 #include "gtkcurve.h"
 #include "gtkdrawingarea.h"
 #include "gtkmain.h"
@@ -37,6 +36,7 @@
 #include "gtkradiobutton.h"
 #include "gtktable.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 #define RADIUS		3	/* radius of the control points */
 #define MIN_DISTANCE	8	/* min distance between control points */
@@ -719,7 +719,7 @@ gtk_curve_set_curve_type (GtkCurve *c, GtkCurveType new_type)
 	  gtk_curve_interpolate (c, width, height);
 	}
       g_signal_emit (c, curve_type_changed_signal, 0);
-      g_object_notify (G_OBJECT (c), "curve_type");
+      g_object_notify (G_OBJECT (c), "curve-type");
       gtk_curve_draw (c, width, height);
     }
 }
@@ -793,7 +793,7 @@ gtk_curve_reset (GtkCurve *c)
   if (old_type != GTK_CURVE_TYPE_SPLINE)
     {
        g_signal_emit (c, curve_type_changed_signal, 0);
-       g_object_notify (G_OBJECT (c), "curve_type");
+       g_object_notify (G_OBJECT (c), "curve-type");
     }
 }
 
@@ -840,19 +840,19 @@ gtk_curve_set_range (GtkCurve *curve,
   g_object_freeze_notify (G_OBJECT (curve));
   if (curve->min_x != min_x) {
      curve->min_x = min_x;
-     g_object_notify (G_OBJECT (curve), "min_x");
+     g_object_notify (G_OBJECT (curve), "min-x");
   }
   if (curve->max_x != max_x) {
      curve->max_x = max_x;
-     g_object_notify (G_OBJECT (curve), "max_x");
+     g_object_notify (G_OBJECT (curve), "max-x");
   }
   if (curve->min_y != min_y) {
      curve->min_y = min_y;
-     g_object_notify (G_OBJECT (curve), "min_y");
+     g_object_notify (G_OBJECT (curve), "min-y");
   }
   if (curve->max_y != max_y) {
      curve->max_y = max_y;
-     g_object_notify (G_OBJECT (curve), "max_y");
+     g_object_notify (G_OBJECT (curve), "max-y");
   }
   g_object_thaw_notify (G_OBJECT (curve));
 
@@ -898,7 +898,7 @@ gtk_curve_set_vector (GtkCurve *c, int veclen, gfloat vector[])
   if (old_type != GTK_CURVE_TYPE_FREE)
     {
        g_signal_emit (c, curve_type_changed_signal, 0);
-       g_object_notify (G_OBJECT (c), "curve_type");
+       g_object_notify (G_OBJECT (c), "curve-type");
     }
 
   gtk_curve_draw (c, c->num_points, height);
@@ -1044,3 +1044,6 @@ gtk_curve_finalize (GObject *object)
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
+
+#define __GTK_CURVE_C__
+#include "gtkaliasdef.c"
