@@ -18,10 +18,10 @@
  */
 
 #include <config.h>
-#include "gtkalias.h"
 #include "gtkentrycompletion.h"
 #include "gtkentryprivate.h"
 #include "gtkcelllayout.h"
+#include "gtkalias.h"
 
 #include "gtkintl.h"
 #include "gtkcellrenderertext.h"
@@ -278,7 +278,7 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
                                    g_param_spec_int ("minimum_key_length",
                                                      P_("Minimum Key Length"),
                                                      P_("Minimum length of the search key in order to look up matches"),
-                                                     -1,
+                                                     0,
                                                      G_MAXINT,
                                                      1,
                                                      G_PARAM_READWRITE));
@@ -303,7 +303,9 @@ gtk_entry_completion_class_init (GtkEntryCompletionClass *klass)
    * GtkEntryCompletion:inline-completion:
    * 
    * Determines whether the common prefix of the possible completions 
-   * should be inserted automatically in the entry.
+   * should be inserted automatically in the entry. Note that this
+   * requires text-column to be set, even if you are using a custom
+   * match function.
    *
    * Since: 2.6
    **/
@@ -942,6 +944,8 @@ gtk_entry_completion_set_model (GtkEntryCompletion *completion,
                            GTK_TREE_MODEL (completion->priv->filter_model));
   g_object_unref (completion->priv->filter_model);
 
+  g_object_notify (G_OBJECT (completion), "model");
+
   if (GTK_WIDGET_VISIBLE (completion->priv->popup_window))
     _gtk_entry_completion_resize_popup (completion);
 }
@@ -1014,9 +1018,14 @@ gtk_entry_completion_set_minimum_key_length (GtkEntryCompletion *completion,
                                              gint                length)
 {
   g_return_if_fail (GTK_IS_ENTRY_COMPLETION (completion));
-  g_return_if_fail (length >= 1);
+  g_return_if_fail (length >= 0);
 
-  completion->priv->minimum_key_length = length;
+  if (completion->priv->minimum_key_length != length)
+    {
+      completion->priv->minimum_key_length = length;
+     
+      g_object_notify (G_OBJECT (completion), "minimum-key-length");
+    }
 }
 
 /**
@@ -1198,7 +1207,7 @@ gtk_entry_completion_set_text_column (GtkEntryCompletion *completion,
                                  cell,
                                  "text", column);
 
-  g_object_notify (G_OBJECT (completion), "text_column");
+  g_object_notify (G_OBJECT (completion), "text-column");
 }
 
 /**
@@ -1405,8 +1414,12 @@ gtk_entry_completion_compute_prefix (GtkEntryCompletion *completion)
   GtkTreeIter iter;
   gchar *prefix = NULL;
   gboolean valid;
+  const gchar *key;
 
-  const gchar *key = gtk_entry_get_text (GTK_ENTRY (completion->priv->entry));
+  if (completion->priv->text_column < 0)
+    return NULL;
+
+  key = gtk_entry_get_text (GTK_ENTRY (completion->priv->entry));
 
   valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (completion->priv->filter_model),
 					 &iter);
@@ -1455,7 +1468,6 @@ gtk_entry_completion_real_insert_prefix (GtkEntryCompletion *completion,
     {
       gint key_len;
       gint prefix_len;
-      gint pos;
       const gchar *key;
 
       prefix_len = g_utf8_strlen (prefix, -1);
@@ -1465,6 +1477,7 @@ gtk_entry_completion_real_insert_prefix (GtkEntryCompletion *completion,
 
       if (prefix_len > key_len)
 	{
+	  gint pos = prefix_len;
 	  gtk_editable_insert_text (GTK_EDITABLE (completion->priv->entry),
 				    prefix + key_len, -1, &pos);
 	  gtk_editable_select_region (GTK_EDITABLE (completion->priv->entry),
@@ -1526,7 +1539,7 @@ gtk_entry_completion_set_inline_completion (GtkEntryCompletion *completion,
     {
       completion->priv->inline_completion = inline_completion;
 
-      g_object_notify (G_OBJECT (completion), "inline_completion");
+      g_object_notify (G_OBJECT (completion), "inline-completion");
     }
 }
 
@@ -1571,7 +1584,7 @@ gtk_entry_completion_set_popup_completion (GtkEntryCompletion *completion,
     {
       completion->priv->popup_completion = popup_completion;
 
-      g_object_notify (G_OBJECT (completion), "popup_completion");
+      g_object_notify (G_OBJECT (completion), "popup-completion");
     }
 }
 
@@ -1593,3 +1606,6 @@ gtk_entry_completion_get_popup_completion (GtkEntryCompletion *completion)
   
   return completion->priv->popup_completion;
 }
+
+#define __GTK_ENTRY_COMPLETION_C__
+#include "gtkaliasdef.c"
