@@ -452,6 +452,9 @@ static void
 do_post_parse_initialization (int    *argc,
 			      char ***argv)
 {
+  if (gtk_initialized)
+    return;
+
   if (g_fatal_warnings)
     {
       GLogLevelFlags fatal_mask;
@@ -464,15 +467,6 @@ do_post_parse_initialization (int    *argc,
   if (gtk_debug_flags & GTK_DEBUG_UPDATES)
     gdk_window_set_debug_updates (TRUE);
 
-#ifdef ENABLE_NLS
-  bindtextdomain (GETTEXT_PACKAGE, GTK_LOCALEDIR);
-  bindtextdomain (GETTEXT_PACKAGE "-properties", GTK_LOCALEDIR);
-#    ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  bind_textdomain_codeset (GETTEXT_PACKAGE "-properties", "UTF-8");
-#    endif
-#endif  
-
   {
   /* Translate to default:RTL if you want your widgets
    * to be RTL, otherwise translate to default:LTR.
@@ -572,6 +566,19 @@ gtk_get_option_group (gboolean open_default_display)
   return group;
 }
 
+static void
+gettext_initialization (void)
+{
+#ifdef ENABLE_NLS
+  bindtextdomain (GETTEXT_PACKAGE, GTK_LOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE "-properties", GTK_LOCALEDIR);
+#    ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  bind_textdomain_codeset (GETTEXT_PACKAGE "-properties", "UTF-8");
+#    endif
+#endif  
+}
+
 /**
  * gtk_init_with_args:
  * @argc: a pointer to the number of command line arguments.
@@ -615,6 +622,8 @@ gtk_init_with_args (int            *argc,
   if (!check_setugid ())
     return FALSE;
 
+  gettext_initialization ();
+
   gtk_group = gtk_get_option_group (TRUE);
   
   context = g_option_context_new (parameter_string);
@@ -660,6 +669,8 @@ gtk_parse_args (int    *argc,
   if (!check_setugid ())
     return FALSE;
 
+  gettext_initialization ();
+
   option_context = g_option_context_new (NULL);
   g_option_context_set_ignore_unknown_options (option_context, TRUE);
   g_option_context_set_help_enabled (option_context, FALSE);
