@@ -24,8 +24,8 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#ifndef GTK_TEXT_BUFFER_H
-#define GTK_TEXT_BUFFER_H
+#ifndef __GTK_TEXT_BUFFER_H__
+#define __GTK_TEXT_BUFFER_H__
 
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkclipboard.h>
@@ -34,9 +34,7 @@
 #include <gtk/gtktextmark.h>
 #include <gtk/gtktextchild.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /*
  * This is the PUBLIC representation of a text buffer.
@@ -197,14 +195,16 @@ void    gtk_text_buffer_insert_with_tags_by_name  (GtkTextBuffer     *buffer,
 
 /* Delete from the buffer */
 void     gtk_text_buffer_delete             (GtkTextBuffer *buffer,
-                                             GtkTextIter   *start,
-                                             GtkTextIter   *end);
+					     GtkTextIter   *start,
+					     GtkTextIter   *end);
 gboolean gtk_text_buffer_delete_interactive (GtkTextBuffer *buffer,
-                                             GtkTextIter   *start_iter,
-                                             GtkTextIter   *end_iter,
-                                             gboolean       default_editable);
-
-
+					     GtkTextIter   *start_iter,
+					     GtkTextIter   *end_iter,
+					     gboolean       default_editable);
+gboolean gtk_text_buffer_backspace          (GtkTextBuffer *buffer,
+					     GtkTextIter   *iter,
+					     gboolean       interactive,
+					     gboolean       default_editable);
 
 /* Obtain strings from the buffer */
 gchar          *gtk_text_buffer_get_text            (GtkTextBuffer     *buffer,
@@ -253,9 +253,12 @@ void gtk_text_buffer_delete_mark_by_name (GtkTextBuffer     *buffer,
 GtkTextMark* gtk_text_buffer_get_insert          (GtkTextBuffer *buffer);
 GtkTextMark* gtk_text_buffer_get_selection_bound (GtkTextBuffer *buffer);
 
-/* efficiently move insert and selection_bound to same location */
+/* efficiently move insert and selection_bound at the same time */
 void gtk_text_buffer_place_cursor (GtkTextBuffer     *buffer,
                                    const GtkTextIter *where);
+void gtk_text_buffer_select_range (GtkTextBuffer     *buffer,
+                                   const GtkTextIter *ins,
+				   const GtkTextIter *bound);
 
 
 
@@ -372,8 +375,6 @@ const PangoLogAttr* _gtk_text_buffer_get_line_log_attrs (GtkTextBuffer     *buff
 void _gtk_text_buffer_notify_will_remove_tag (GtkTextBuffer *buffer,
                                               GtkTextTag    *tag);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
