@@ -31,7 +31,6 @@
 #include <config.h>
 
 #include <string.h>
-#include "gtkalias.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
 #include "gtkmenu.h"
@@ -42,6 +41,7 @@
 #include "gtktearoffmenuitem.h"
 #include "gtktoolbar.h"
 #include "gtkuimanager.h"
+#include "gtkalias.h"
 
 #undef DEBUG_UI_MANAGER
 
@@ -574,7 +574,7 @@ gtk_ui_manager_set_add_tearoffs (GtkUIManager *self,
       
       dirty_all_nodes (self);
 
-      g_object_notify (G_OBJECT (self), "add_tearoffs");
+      g_object_notify (G_OBJECT (self), "add-tearoffs");
     }
 }
 
@@ -1959,7 +1959,6 @@ update_smart_separators (GtkWidget *proxy)
   else if (GTK_IS_MENU_ITEM (proxy) || GTK_IS_TOOL_ITEM (proxy))
     parent = gtk_widget_get_parent (proxy);
 
-  
   if (parent) 
     {
       gboolean visible;
@@ -1980,10 +1979,11 @@ update_smart_separators (GtkWidget *proxy)
       while (cur) 
 	{
 	  if (g_object_get_data (cur->data, "gtk-empty-menu-item"))
-	    filler = cur->data;
-
-	  if (GTK_IS_SEPARATOR_MENU_ITEM (cur->data) ||
-	      GTK_IS_SEPARATOR_TOOL_ITEM (cur->data))
+	    {
+	      filler = cur->data;
+	    }
+	  else if (GTK_IS_SEPARATOR_MENU_ITEM (cur->data) ||
+		   GTK_IS_SEPARATOR_TOOL_ITEM (cur->data))
 	    {
 	      gint mode = 
 		GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cur->data), 
@@ -2056,7 +2056,6 @@ update_node (GtkUIManager *self,
   Node *info;
   GNode *child;
   GtkAction *action;
-  gchar *tooltip;
   const gchar *action_name;
   NodeUIReference *ref;
   
@@ -2441,9 +2440,7 @@ update_node (GtkUIManager *self,
 	       * tooltips on toolitems can't be set before the toolitem 
 	       * is added to the toolbar.
 	       */
-	      g_object_get (action, "tooltip", &tooltip, NULL);
-	      g_object_set (action, "tooltip", tooltip, NULL);
-	      g_free (tooltip);
+              g_object_notify (G_OBJECT (action), "tooltip");
 	    }
 	}
       else
@@ -2662,7 +2659,7 @@ mark_node_dirty (GNode *node)
     NODE_INFO (p)->dirty = TRUE;  
 }
 
-static const gchar *open_tag_format[] = {
+static const gchar *const open_tag_format[] = {
   "%*s<UNDECIDED",
   "%*s<ui",
   "%*s<menubar",
@@ -2677,7 +2674,7 @@ static const gchar *open_tag_format[] = {
   "%*s<accelerator"
 };
 
-static const gchar *close_tag_format[] = {
+static const gchar *const close_tag_format[] = {
   "%*s</UNDECIDED>\n",
   "%*s</ui>\n",
   "%*s</menubar>\n",
@@ -2752,3 +2749,29 @@ gtk_ui_manager_get_ui (GtkUIManager *self)
   return g_string_free (buffer, FALSE);
 }
 
+#ifdef G_OS_WIN32
+
+#undef gtk_ui_manager_add_ui_from_file
+
+guint
+gtk_ui_manager_add_ui_from_file (GtkUIManager *self,
+				 const gchar  *filename,
+				 GError      **error)
+{
+  gchar *utf8_filename = g_locale_to_utf8 (filename, -1, NULL, NULL, error);
+  guint retval;
+
+  if (utf8_filename == NULL)
+    return 0;
+  
+  retval = gtk_ui_manager_add_ui_from_file_utf8 (self, utf8_filename, error);
+
+  g_free (utf8_filename);
+
+  return retval;
+}
+
+#endif
+
+#define __GTK_UI_MANAGER_C__
+#include "gtkaliasdef.c"
